Index: /gsdl/trunk/src/colservr/collectset.cpp
===================================================================
--- /gsdl/trunk/src/colservr/collectset.cpp	(revision 15583)
+++ /gsdl/trunk/src/colservr/collectset.cpp	(revision 15584)
@@ -29,4 +29,5 @@
 #include "colservrconfig.h"
 #include "gsdlsitecfg.h"
+#include "gdbmclass.h"
 #include "filter.h"
 #include "browsefilter.h"
@@ -239,5 +240,5 @@
     // add a mg and gdbm source
     mggdbmsourceclass *mggdbmsource = new mggdbmsourceclass ();
-    mggdbmsource->set_gdbmptr (gdbmhandler);
+    mggdbmsource->set_db_ptr (gdbmhandler);
     mggdbmsource->set_textsearchptr (mgsearch);
     cserver->add_source (mggdbmsource);
@@ -254,5 +255,5 @@
     // add a mg and gdbm source
     mggdbmsourceclass *mggdbmsource = new mggdbmsourceclass ();
-    mggdbmsource->set_gdbmptr (gdbmhandler);
+    mggdbmsource->set_db_ptr (gdbmhandler);
     mggdbmsource->set_textsearchptr (mgppsearch);
     cserver->add_source (mggdbmsource);
@@ -270,5 +271,5 @@
     // add a lucene and gdbm source
     lucenegdbmsourceclass *lucenegdbmsource = new lucenegdbmsourceclass ();
-    lucenegdbmsource->set_gdbmptr (gdbmhandler);
+    lucenegdbmsource->set_db_ptr (gdbmhandler);
     lucenegdbmsource->set_textsearchptr (lucenesearch);
     cserver->add_source (lucenegdbmsource);
Index: /gsdl/trunk/src/colservr/gdbmsource.cpp
===================================================================
--- /gsdl/trunk/src/colservr/gdbmsource.cpp	(revision 15583)
+++ /gsdl/trunk/src/colservr/gdbmsource.cpp	(revision 15584)
@@ -31,5 +31,5 @@
 
 gdbmsourceclass::gdbmsourceclass () {
-  gdbmptr = NULL;
+  db_ptr = NULL;
   textsearchptr = NULL;
   classname = "gdbmsource";
@@ -37,5 +37,5 @@
 
 gdbmsourceclass::~gdbmsourceclass () {
-  if (gdbmptr != NULL) delete gdbmptr;
+  if (db_ptr != NULL) delete db_ptr;
   if (textsearchptr != NULL) delete textsearchptr;
 }
@@ -117,13 +117,12 @@
     indexstem = collection;
   }
-  gdbm_filename = filename_cat(gdbmhome, "collect", collection, "index", "text", indexstem);
-  if (littleEndian()) gdbm_filename += ".ldb";
-  else gdbm_filename += ".bdb";
-
-  if (!file_exists(gdbm_filename)) {
+  db_filename = filename_cat(gdbmhome, "collect", collection, "index", "text", indexstem);
+  if (littleEndian()) db_filename += ".ldb";
+  else db_filename += ".bdb";
+
+  if (!file_exists(db_filename)) {
     logout << text_t2ascii
-	   << "warning: gdbm database \"" //****
-	   << gdbm_filename << "\" does not exist\n\n";
-    // return false; //****
+	   << "warning: database \"" << db_filename << "\" does not exist\n\n";
+    // return false;
   }
   
@@ -137,8 +136,8 @@
 
   err = noError;
-  if (gdbmptr == NULL) {
+  if (db_ptr == NULL) {
     // most likely a configuration problem
     logout << text_t2ascii 
-	   << "configuration error: " << classname << " contains a null gdbmclass\n\n";
+	   << "configuration error: " << classname << " contains a null dbclass\n\n";
     err = configurationError;
     return true;
@@ -146,11 +145,9 @@
 
   // open the database
-  gdbmptr->setlogout(&logout);
-  if (!gdbmptr->opendatabase (gdbm_filename, GDBM_READER, 100, false)) {
-    // most likely a system problem (we have already checked that the
-    // gdbm database exists)
+  db_ptr->setlogout(&logout);
+  if (!db_ptr->opendatabase (db_filename, DB_READER, 100, false)) {
+    // most likely a system problem (we have already checked that the database exists)
     logout << text_t2ascii
-	   << "system problem: open on gdbm database \""
-	   << gdbm_filename << "\" failed\n\n";
+	   << "system problem: open on database \"" << db_filename << "\" failed\n\n";
     err = systemProblem;
     return true;
@@ -158,6 +155,6 @@
 
   infodbclass info;
-  OIDout = gdbmptr->translate_OID (OIDin, info);
-  gdbmptr->closedatabase();  // Important that local library doesn't leave any files open
+  OIDout = db_ptr->translate_OID (OIDin, info);
+  db_ptr->closedatabase();  // Important that local library doesn't leave any files open
   return true;
 }
@@ -172,8 +169,8 @@
 
   err = noError;
-  if (gdbmptr == NULL) {
+  if (db_ptr == NULL) {
     // most likely a configuration problem
     logout << text_t2ascii 
-	   << "configuration error: " << classname <<" contains a null gdbmclass\n\n";
+	   << "configuration error: " << classname <<" contains a null dbclass\n\n";
     err = configurationError;
     return true;
@@ -181,11 +178,9 @@
 
   // open the database
-  gdbmptr->setlogout(&logout);
-  if (!gdbmptr->opendatabase (gdbm_filename, GDBM_READER, 100, false)) {
-    // most likely a system problem (we have already checked that the
-    // gdbm database exists)
+  db_ptr->setlogout(&logout);
+  if (!db_ptr->opendatabase (db_filename, DB_READER, 100, false)) {
+    // most likely a system problem (we have already checked that the database exists)
     logout << text_t2ascii
-	   << "system problem: open on gdbm database \""
-	   << gdbm_filename << "\" failed\n\n";
+	   << "system problem: open on database \"" << db_filename << "\" failed\n\n";
     err = systemProblem;
     return true;
@@ -204,5 +199,5 @@
   while (this_OID != end_OID) {
     infodbclass info;
-    if (!gdbmptr->getinfo(*this_OID, info)) return false;
+    if (!db_ptr->getinfo(*this_OID, info)) return false;
 
     // adjust the metadata
@@ -260,5 +255,5 @@
 	      parentOID = thisparent;
 	      parentcontents.erase(parentcontents.begin(), parentcontents.end());
-	      if (gdbmptr->getinfo(parentOID, parentinfo)) {
+	      if (db_ptr->getinfo(parentOID, parentinfo)) {
 		text_t &parentinfocontains = parentinfo["contains"];
 		if (!parentinfocontains.empty())
@@ -316,5 +311,5 @@
   }
 
-  gdbmptr->closedatabase();  // Important that local library doesn't leave any files open
+  db_ptr->closedatabase();  // Important that local library doesn't leave any files open
   return true;
 }
@@ -327,8 +322,8 @@
 
   err = noError;
-  if (gdbmptr == NULL) {
+  if (db_ptr == NULL) {
     // most likely a configuration problem
     logout << text_t2ascii 
-	   << "configuration error: " << classname << " contains a null gdbmclass\n\n";
+	   << "configuration error: " << classname << " contains a null dbclass\n\n";
     err = configurationError;
     return true;
@@ -336,11 +331,9 @@
 
   // open the database
-  gdbmptr->setlogout(&logout);
-  if (!gdbmptr->opendatabase (gdbm_filename, GDBM_READER, 100, false)) {
-    // most likely a system problem (we have already checked that the
-    // gdbm database exists)
+  db_ptr->setlogout(&logout);
+  if (!db_ptr->opendatabase (db_filename, DB_READER, 100, false)) {
+    // most likely a system problem (we have already checked that the database exists)
     logout << text_t2ascii
-	   << "system problem: open on gdbm database \""
-	   << gdbm_filename << "\" failed\n\n";
+	   << "system problem: open on database \"" << db_filename << "\" failed\n\n";
     err = systemProblem;
     return true;
@@ -351,6 +344,6 @@
     translate_OID (OID, tOID, err, logout);
   infodbclass info;
-  if (!gdbmptr->getinfo(tOID, info)) {
-    gdbmptr->closedatabase();  // Important that local library doesn't leave any files open
+  if (!db_ptr->getinfo(tOID, info)) {
+    db_ptr->closedatabase();  // Important that local library doesn't leave any files open
     return false;
   }
@@ -367,5 +360,5 @@
   }
 
-  gdbmptr->closedatabase();  // Important that local library doesn't leave any files open
+  db_ptr->closedatabase();  // Important that local library doesn't leave any files open
   return true;
 }
Index: /gsdl/trunk/src/colservr/lucenegdbmsource.cpp
===================================================================
--- /gsdl/trunk/src/colservr/lucenegdbmsource.cpp	(revision 15583)
+++ /gsdl/trunk/src/colservr/lucenegdbmsource.cpp	(revision 15584)
@@ -44,8 +44,8 @@
   outconvertclass text_t2ascii;
   err = noError;
-  if (gdbmptr == NULL) {
+  if (db_ptr == NULL) {
     // most likely a configuration problem
     logout << text_t2ascii 
-	   << "configuration error: lucenegdbmsource contains a null gdbmclass\n\n";
+	   << "configuration error: lucenegdbmsource contains a null dbclass\n\n";
     err = configurationError;
     return true;
@@ -53,11 +53,9 @@
 
   // open the database
-  gdbmptr->setlogout(&logout);
-  if (!gdbmptr->opendatabase (gdbm_filename, GDBM_READER, 100, false)) {
-    // most likely a system problem (we have already checked that the
-    // gdbm database exists)
+  db_ptr->setlogout(&logout);
+  if (!db_ptr->opendatabase (db_filename, DB_READER, 100, false)) {
+    // most likely a system problem (we have already checked that the database exists)
     logout << text_t2ascii
-	   << "system problem: open on gdbm database \""
-	   << gdbm_filename << "\" failed\n\n";
+	   << "system problem: open on database \"" << db_filename << "\" failed\n\n";
     err = systemProblem;
     return true;
@@ -68,6 +66,6 @@
     translate_OID (OID, tOID, err, logout);
   infodbclass info;
-  if (!gdbmptr->getinfo(tOID, info)) {
-    gdbmptr->closedatabase();  // Important that local library doesn't leave any files open
+  if (!db_ptr->getinfo(tOID, info)) {
+    db_ptr->closedatabase();  // Important that local library doesn't leave any files open
     return false;
   }
@@ -82,7 +80,6 @@
   get_top(tOID, parent_OID);
   
-  // locate the parent info ingdbm db
-  if (!gdbmptr->getinfo(parent_OID, info)) {
-    gdbmptr->closedatabase();  // Important that local library doesn't leave any files open
+  if (!db_ptr->getinfo(parent_OID, info)) {
+    db_ptr->closedatabase();  // Important that local library doesn't leave any files open
     return false;
   }
@@ -92,5 +89,5 @@
   
   doc.clear();
-  gdbmptr->closedatabase();  // Important that local library doesn't leave any files open
+  db_ptr->closedatabase();  // Important that local library doesn't leave any files open
   expat_document(full_path_to_doc, ((lucenesearchclass*)textsearchptr)->gdbm_level, text_t(docnum), doc);
   return true;

Index: /gsdl/trunk/src/colservr/gdbmsource.h
===================================================================
--- /gsdl/trunk/src/colservr/gdbmsource.h	(revision 15583)
+++ /gsdl/trunk/src/colservr/gdbmsource.h	(revision 15584)
@@ -31,5 +31,5 @@
 #include "text_t.h"
 #include "comtypes.h"
-#include "gdbmclass.h"
+#include "dbclass.h"
 #include "maptools.h"
 #include "search.h"
@@ -59,6 +59,6 @@
   text_tarray parentcontents;
 
-  text_t gdbm_filename;
-  gdbmclass *gdbmptr;
+  text_t db_filename;
+  dbclass *db_ptr;
   
   searchclass *textsearchptr;
@@ -68,8 +68,8 @@
   virtual ~gdbmsourceclass ();
 
-  // the gdbmptr remains the responsability of the calling code
-  void set_gdbmptr (gdbmclass *thegdbmptr) {gdbmptr=thegdbmptr;}
+  // the DB ptr remains the responsibility of the calling code
+  void set_db_ptr (dbclass *db_ptr_arg) { db_ptr = db_ptr_arg; }
 
-  // the textsearchptr remains the responsability of the calling code
+  // the textsearchptr remains the responsibility of the calling code
   void set_textsearchptr (searchclass *thetextsearchptr) {textsearchptr=thetextsearchptr;}
 